@@ -71,6 +71,64 @@ def valid_spec_122_headers(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "TAZIMUTH": 3.0,
+        "TELTRACK": "None",
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "clear",
+        "PAC__003": "none",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_122_headers_temp")
@@ -183,6 +241,62 @@ def valid_compressed_spec_122_headers(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "clear",
+        "PAC__003": "none",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid comp_122_headers_temp")
@@ -280,6 +394,62 @@ def valid_visp_122_headers(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "clear",
+        "PAC__003": "none",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid visp_122_headers_temp")
@@ -376,6 +546,62 @@ def valid_spec_122_headers_datainsecondHDU(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "clear",
+        "PAC__003": "none",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_122_headers_temp")
@@ -517,14 +743,6 @@ def valid_spec_214_headers(tmpdir_factory):
         "OBSRVTRY": "Haleakala High Altitude Observatory Site",
         "HISTORY": "Old History",
         "COMMENT": "A comment",
-        "DATE-OBS": "2017-05-30T00:46:13.952",
-        "WAVELNTH": 582.3,
-        "ID___002": "fileid",
-        "ID___008": "opexecutionid",
-        "ID___013": "proposalid",
-        "DKIST003": "observe",
-        "DKIST004": "dark",
-        "ID___004": "LKNDFPONP93HR08BG",
         "DKISTVER": "NEWESTVERSION",
         "CAMERA": "CAMERA 1",
         "WAVEUNIT": -9,
@@ -537,6 +755,57 @@ def valid_spec_214_headers(tmpdir_factory):
         "OBS_VR": 13.2,
         "NSUMEXP": 3,
         "XPOSURE": 13.2,
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "INFO_URL": "url string",
+        "CAL_URL": "url string",
+        "HEAD_URL": "url string",
+        "DSP_ID": "id_string",
+        "IP_ID": "id string",
+        "HEADVERS": "version string",
+        "CALVERS": "version string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_214_headers_temp")
@@ -709,6 +978,57 @@ def valid_spec_214_headers_toomanyHDUs(tmpdir_factory):
         "OBS_VR": 13.2,
         "NSUMEXP": 3,
         "XPOSURE": 13.2,
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "INFO_URL": "url string",
+        "CAL_URL": "url string",
+        "HEAD_URL": "url string",
+        "DSP_ID": "id_string",
+        "IP_ID": "id string",
+        "HEADVERS": "version string",
+        "CALVERS": "version string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_214_headers_temp")
@@ -871,6 +1191,57 @@ def valid_spec_214_headers_datainsecondHDU(tmpdir_factory):
         "OBS_VR": 13.2,
         "NSUMEXP": 3,
         "XPOSURE": 13.2,
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "INFO_URL": "url string",
+        "CAL_URL": "url string",
+        "HEAD_URL": "url string",
+        "DSP_ID": "id_string",
+        "IP_ID": "id string",
+        "HEADVERS": "version string",
+        "CALVERS": "version string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_214_headers_temp")
