@@ -52,6 +52,17 @@ def test_spec122_return_BytesIO(valid_spec_122_file):
     spec122_validator.validate(valid_spec_122_file, return_type=BytesIO, extra=False)
 
 
+def test_spec122_return_HDU(valid_spec_122_file):
+    """
+    Validates a fits header against the SPEC-122 schema
+    Given: A valid SPEC-122 fits header
+    When: Validating headers
+    Then: return validated PrimaryHDU object and do not raise an exception
+    """
+    # raises exception on failure
+    spec122_validator.validate(valid_spec_122_file, return_type=fits.PrimaryHDU, extra=False)
+
+
 def test_spec122_return_file(valid_spec_122_file):
     """
     Validates a fits header against the SPEC-122 schema
@@ -157,8 +168,8 @@ def max_headers(tmpdir_factory):
         "CAM__019": 763903,
         "CAM__020": 626497,
         "PAC__001": "open",
-        "PAC__002": "Clear",
-        "PAC__003": "Undefined",
+        "PAC__002": "clear",
+        "PAC__003": "undefined",
         "PAC__004": "clear",
         "PAC__005": "186BGJFTFDVEOECZ80ENVCKM5RZL4U",
         "PAC__006": "clear",
@@ -185,6 +196,62 @@ def max_headers(tmpdir_factory):
         "PC3_1": 13.5,
         "PC3_3": 13.5,
         "HISTORY": "Old History",
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "clear",
+        "PAC__003": "none",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("max_headers_temp")
