@@ -202,6 +202,57 @@ def valid_spec_214_extraheaders(tmpdir_factory):
         "OBS_VR": 13.2,
         "NSUMEXP": 3,
         "XPOSURE": 13.2,
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "INFO_URL": "url string",
+        "CAL_URL": "url string",
+        "HEAD_URL": "url string",
+        "DSP_ID": "id_string",
+        "IP_ID": "id string",
+        "HEADVERS": "version string",
+        "CALVERS": "version string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_214_extraheaders_temp")
@@ -410,10 +461,10 @@ def max_headers(tmpdir_factory):
         "CHECKSUM": "33989WFLS3IVX0LLYTQW3U1PT8AKFG",
         "GOS_STAT": "open",
         "PAC__001": "Open",
-        "LVL3STAT": "Clear",
-        "PAC__002": "Clear",
-        "LAMPSTAT": "On",
-        "PAC__003": "On",
+        "LVL3STAT": "clear",
+        "PAC__002": "clear",
+        "LAMPSTAT": "on",
+        "PAC__003": "on",
         "LVL2STAT": "clear",
         "PAC__004": "Clear",
         "POLANGLE": "186BGJFTFDVEOECZ80ENVCKM5RZL4U",
@@ -559,6 +610,57 @@ def max_headers(tmpdir_factory):
         "OBS_VR": 13.2,
         "NSUMEXP": 3,
         "XPOSURE": 13.2,
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "INFO_URL": "url string",
+        "CAL_URL": "url string",
+        "HEAD_URL": "url string",
+        "DSP_ID": "id_string",
+        "IP_ID": "id string",
+        "HEADVERS": "version string",
+        "CALVERS": "version string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("max_headers_temp")
@@ -720,6 +822,57 @@ def valid_compressed_spec_214_headers(tmpdir_factory):
         "OBS_VR": 13.2,
         "NSUMEXP": 3,
         "XPOSURE": 13.2,
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "INFO_URL": "url string",
+        "CAL_URL": "url string",
+        "HEAD_URL": "url string",
+        "DSP_ID": "id_string",
+        "IP_ID": "id string",
+        "HEADVERS": "version string",
+        "CALVERS": "version string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid comp_214_headers_temp")
@@ -853,6 +1006,109 @@ def valid_l0_spec_214_headers(tmpdir_factory):
         "CAM__004": 13.2,
         "CAM__014": 3,
         "FILE_ID": "RANDOMSTRING",
+        "APERTURE": "None",
+        "BITDEPTH": 12,
+        "CAM_FPS": 12.3,
+        "CAM_ID": "string",
+        "CHIPDIM1": 12,
+        "CHIPDIM2": 12,
+        "DSHEALTH": "Good",
+        "FIDO_CFG": "string",
+        "GOS_STAT": "open",
+        "GOS_TEMP": 12.3,
+        "HWBIN1": 12,
+        "HWBIN2": 12,
+        "HWNROI": 12,
+        "HWROI1OX": 12,
+        "HWROI1OY": 12,
+        "HWROI1SX": 12,
+        "HWROI1SY": 12,
+        "LAMPSTAT": "none",
+        "LGOSSTAT": "open",
+        "LIGHTLVL": 12.3,
+        "LVL0STAT": "NonRedArray",
+        "LVL1STAT": "clear",
+        "LVL2STAT": "clear",
+        "LVL3STAT": "clear",
+        "OCS_CTRL": "Auto",
+        "POLANGLE": 12.3,
+        "RETANGLE": 12.3,
+        "SKYBRIGT": 12.3,
+        "SWBIN1": 12,
+        "SWBIN2": 12,
+        "SWNROI": 12,
+        "SWROI1OX": 12,
+        "SWROI1OY": 12,
+        "SWROI1SX": 12,
+        "SWROI1SY": 12,
+        "WIND_DIR": 0,
+        "WIND_SPD": 12.3,
+        "WSSOURCE": "string",
+        "WS_DEWPT": 12.3,
+        "WS_HUMID": 12.3,
+        "WS_PRESS": 12.3,
+        "WS_TEMP": 12.3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "clear",
+        "PAC__003": "none",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
+        "ID___004": "String",
+        "DSP_ID": "id string",
+        "IP_ID": "id string",
+        "DSPSREPS": 12,
+        "DSPSNUM": 12,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid l0_214_headers_temp")
