@@ -1,10 +1,13 @@
 from pathlib import Path
 
+import astropy.io.fits
 import numpy as np
 import pytest
 from astropy.io import fits
 
-from dkist_header_validator.translator import convert_spec122_to_spec214
+from dkist_header_validator.translator import sanitize_to_spec214_level1
+from dkist_header_validator.translator import translate_spec122_to_spec214
+from dkist_header_validator.translator import translate_spec122_to_spec214_l0
 
 
 @pytest.fixture(scope="module")
@@ -70,6 +73,62 @@ def valid_spec_122_headers(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "Clear",
+        "PAC__003": "None",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid spec_122_headers_temp")
@@ -103,15 +162,14 @@ def valid_spec_122_header(request, valid_spec_122_headers):
     yield valid_spec_122_headers[request.param]
 
 
-def test_spec122_valid(valid_spec_122_header):
+def test_spec122_to_214_l0_valid(valid_spec_122_header):
     """
-    Translates a SPEC-0122 object to a SPEC-214 object
+    Strips headers down to a 214 L1 object
     Given: A valid SPEC-0122 object
-    When: Translating headers
-    Then: For a fits file input, return a HDUList and do not raise an exception
-          For a dict, HDUList, or header input, return a dictionary and do not raise an exception
+    When: Sanitizing headers
+    Then:
     """
-    convert_spec122_to_spec214(valid_spec_122_header)
+    translate_spec122_to_spec214_l0(valid_spec_122_header)
 
 
 @pytest.fixture(scope="module")
@@ -173,6 +231,62 @@ def spec_122_headers_missing_required_keys(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "Clear",
+        "PAC__003": "None",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("spec_122_headers_missing_required_keys_temp")
@@ -206,7 +320,19 @@ def missing_required_keys_spec_122_header(request, spec_122_headers_missing_requ
     yield spec_122_headers_missing_required_keys[request.param]
 
 
-def test_spec122_missing_required_keys(missing_required_keys_spec_122_header):
+def test_spec122_to_214_l0_missing_required_keys(missing_required_keys_spec_122_header):
+    """
+    Translates an invalid SPEC-0122 object missing required
+    keys to a SPEC-214 l0 object
+    Given: A valid SPEC-0122 object
+    When: Translating headers
+    Then: Raises a KeyError exception
+    """
+    with pytest.raises(KeyError):
+        translate_spec122_to_spec214_l0(missing_required_keys_spec_122_header)
+
+
+def test_spec122_to_214_missing_required_keys(missing_required_keys_spec_122_header):
     """
     Translates an invalid SPEC-0122 object missing required
     keys to a SPEC-214 object
@@ -215,7 +341,7 @@ def test_spec122_missing_required_keys(missing_required_keys_spec_122_header):
     Then: Raises a KeyError exception
     """
     with pytest.raises(KeyError):
-        convert_spec122_to_spec214(missing_required_keys_spec_122_header)
+        translate_spec122_to_spec214(missing_required_keys_spec_122_header)
 
 
 @pytest.fixture(scope="module")
@@ -341,6 +467,62 @@ def max_headers(tmpdir_factory):
         "WS___005": 282679.0410177523,
         "WS___006": 348537.5489154414,
         "WS___007": 870761.4045310392,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "Clear",
+        "PAC__003": "None",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("max_headers_temp")
@@ -356,7 +538,20 @@ def max_headers(tmpdir_factory):
     yield Path(str(file_name))
 
 
-def test_translate_maxheaders(max_headers):
+def test_translate_to_214_l0_maxheaders(max_headers):
+    """
+    Translates a SPEC-0122 object with a large number of keywords
+    to a SPEC-214 l0 object and validates output against the SPEC-214 l0 schema
+    Given: A valid SPEC-0122 object with many header keywords
+    When: Translating headers
+    Then: For a fits file input, return a HDUList and do not raise an exception
+          For a dict, HDUList, or header input, return a dictionary and do not raise an exception
+    """
+
+    translate_spec122_to_spec214_l0(max_headers)
+
+
+def test_translate_to_214_maxheaders(max_headers):
     """
     Translates a SPEC-0122 object with a large number of keywords
     to a SPEC-214 object and validates output against the SPEC-214 schema
@@ -365,8 +560,7 @@ def test_translate_maxheaders(max_headers):
     Then: For a fits file input, return a HDUList and do not raise an exception
           For a dict, HDUList, or header input, return a dictionary and do not raise an exception
     """
-
-    convert_spec122_to_spec214(max_headers)
+    translate_spec122_to_spec214(max_headers)
 
 
 @pytest.fixture(scope="module")
@@ -433,6 +627,62 @@ def valid_compressed_spec_122_headers(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "Clear",
+        "PAC__003": "None",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("valid comp_122_headers_temp")
@@ -461,14 +711,24 @@ def valid_compressed_spec_122_header(request, valid_compressed_spec_122_headers)
     yield valid_compressed_spec_122_headers[request.param]
 
 
-def test_compressed_spec122_valid(valid_compressed_spec_122_header):
+def test_compressed_spec122_to_214_l0_valid(valid_compressed_spec_122_header):
+    """
+    Translates a compressed SPEC-0122 object to a SPEC-214 l0 object
+    Given: A valid compressed SPEC-0122 file
+    When: Translating headers
+    Then: Return a HDUList and do not raise an exception
+    """
+    translate_spec122_to_spec214_l0(valid_compressed_spec_122_header)
+
+
+def test_compressed_spec122_to_214_valid(valid_compressed_spec_122_header):
     """
     Translates a compressed SPEC-0122 object to a SPEC-214 object
     Given: A valid compressed SPEC-0122 file
     When: Translating headers
     Then: Return a HDUList and do not raise an exception
     """
-    convert_spec122_to_spec214(valid_compressed_spec_122_header)
+    translate_spec122_to_spec214(valid_compressed_spec_122_header)
 
 
 @pytest.fixture(scope="module")
@@ -527,6 +787,62 @@ def compressed_spec_122_headers_missing_required_keys(tmpdir_factory):
         "CAM__005": 126.3,
         "CAM__004": 13.2,
         "CAM__014": 3,
+        "CAM__001": "string",
+        "CAM__003": 12,
+        "CAM__006": 13.2,
+        "CAM__007": 12,
+        "CAM__008": 12,
+        "CAM__009": 12,
+        "CAM__010": 15,
+        "CAM__011": 18,
+        "CAM__012": 15,
+        "CAM__013": 16,
+        "CAM__015": 18,
+        "CAM__016": 18,
+        "CAM__017": 18,
+        "CAM__018": 18,
+        "CAM__019": 20,
+        "CAM__020": 18,
+        "CAM__033": 18,
+        "CAM__034": 18,
+        "CAM__035": 18,
+        "CAM__036": 18,
+        "CAM__037": 20,
+        "DKIST001": "Auto",
+        "DKIST002": "Full",
+        "DKIST005": "fidocfg",
+        "DKIST006": "Good",
+        "DKIST007": True,
+        "DKIST008": 12,
+        "DKIST009": 12,
+        "DKIST010": 12.3,
+        "ID___003": "string",
+        "ID___005": "string",
+        "ID___006": "string",
+        "ID___007": "string",
+        "ID___009": "string",
+        "ID___010": "string",
+        "ID___011": "string",
+        "ID___014": "string",
+        "PAC__001": "open",
+        "PAC__002": "Clear",
+        "PAC__003": "None",
+        "PAC__004": "clear",
+        "PAC__005": 12.3,
+        "PAC__006": "clear",
+        "PAC__007": 12.3,
+        "PAC__008": "NonRedArray",
+        "PAC__009": "None",
+        "PAC__010": "open",
+        "PAC__011": 12.3,
+        "WS___001": "string",
+        "WS___002": 12.3,
+        "WS___003": 0,
+        "WS___004": 12.3,
+        "WS___005": 12.3,
+        "WS___006": 12.3,
+        "WS___007": 15.8,
+        "WS___008": 13.8,
     }
 
     temp_dir = tmpdir_factory.mktemp("comp_122_headers_missing_required_keys_temp")
@@ -558,13 +874,75 @@ def compressed_spec_122_header_missing_required_keys(
     yield compressed_spec_122_headers_missing_required_keys[request.param]
 
 
-def test_compressed_spec122_missing_required_keys(compressed_spec_122_header_missing_required_keys):
+def test_compressed_spec122_to_214_l0_missing_required_keys(
+    compressed_spec_122_header_missing_required_keys,
+):
     """
     Translates a compressed SPEC-0122 object which is
-    missing required keys to a SPEC-214 object
+    missing required keys to a SPEC-214 l0 object
     Given: A valid compressed SPEC-0122 file
     When: Translating headers
     Then: Raises a KeyError exception
     """
     with pytest.raises(KeyError):
-        convert_spec122_to_spec214(compressed_spec_122_header_missing_required_keys)
+        translate_spec122_to_spec214_l0(compressed_spec_122_header_missing_required_keys)
+
+
+def test_compressed_spec122_to_214_missing_required_keys(
+    compressed_spec_122_header_missing_required_keys,
+):
+    """
+    Translates a compressed SPEC-0122 object which is
+    missing required keys to a SPEC-214 l0 object
+    Given: A valid compressed SPEC-0122 file
+    When: Translating headers
+    Then: Raises a KeyError exception
+    """
+    with pytest.raises(KeyError):
+        translate_spec122_to_spec214(compressed_spec_122_header_missing_required_keys)
+
+
+def test_translate_and_sanitize(valid_spec_122_header):
+    """
+    Translates a SPEC-0122 object to a SPEC-214 L1 object and sanitizes
+    Given: A valid SPEC-0122 object
+    When: Translating and stripping down headers to 214 L1 (no 122 headers)
+    Then: For a header or a dict, return a fits header and do not raise an exception
+          For an HDUList or a file, return an HDUList and do not raise an exception
+    """
+    s214_header = translate_spec122_to_spec214(valid_spec_122_header)
+    sanitize_to_spec214_level1(s214_header)
+
+
+def test_sanitize_s122(valid_spec_122_header):
+    """
+    Tries to sanitize a Spec-0122 object
+    Given: A valid SPEC-0122 object
+    When: Stripping down headers to 214 L1 (no 122 headers)
+    Then: Raises a TypeError exception
+    """
+    with pytest.raises(TypeError):
+        sanitize_to_spec214_level1(valid_spec_122_header)
+
+
+def test_sanitize_trsnslated_s214l0(valid_spec_122_header):
+    """
+    Tries to sanitize a Spec-214 L0 object
+    Given: A valid SPEC-0122 object
+    When: Translating and stripping down headers to 214 L1 (no 122 headers)
+    Then: Raises a TypeError exception
+    """
+    s214_l0_header = translate_spec122_to_spec214_l0(valid_spec_122_header)
+    with pytest.raises(TypeError):
+        sanitize_to_spec214_level1(s214_l0_header)
+
+
+def test_sanitize(valid_spec_214_header):
+    """
+    Sanitizes a SPEC-214 L1 object
+    Given: A valid SPEC-214 L1 object
+    When: Stripping down headers to 214 L1 (no 122 headers)
+    Then: For a header or a dict, return a fits header and do not raise an exception
+          For an HDUList or a file, return an HDUList and do not raise an exception
+    """
+    sanitize_to_spec214_level1(valid_spec_214_header)
